@@ -36,11 +36,12 @@ class VersionProps {
     private static final String launcher_name =
         "openjdk";
 
+    // This field is read by HotSpot
     private static final String java_version =
-        "15.0.1";
+        "17.0.3";
 
     private static final String java_version_date =
-        "2020-10-20";
+        "2022-04-19";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -48,49 +49,49 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "15.0.1+9-18";
+        "17.0.3+7";
 
     private static final String VERSION_NUMBER =
-        "15.0.1";
+        "17.0.3";
 
     private static final String VERSION_SPECIFICATION =
-        "15";
+        "17";
 
     private static final String VERSION_BUILD =
-        "9";
+        "7";
 
     private static final String VERSION_PRE =
         "";
 
     private static final String VERSION_OPT =
-        "18";
+        "";
 
     private static final boolean isLTS =
-        "18".startsWith("LTS");
+        "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "59.0";
+        "61.0";
 
     private static final String VENDOR =
-        "Oracle Corporation";
+        "Eclipse Adoptium";
 
     private static final String VENDOR_URL =
-        "https://java.oracle.com/";
+        "https://adoptium.net/";
 
     // The remaining VENDOR_* fields must not be final,
     // so that they can be redefined by jlink plugins
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "";
+        "Temurin-17.0.3+7";
 
     private static String VENDOR_URL_BUG =
-        "https://bugreport.java.com/bugreport/";
+        "https://github.com/adoptium/adoptium-support/issues";
 
     // This field is read by HotSpot
     @SuppressWarnings("unused")
     private static String VENDOR_URL_VM_BUG =
-        "https://bugreport.java.com/bugreport/crash.jsp";
+        "https://github.com/adoptium/adoptium-support/issues";
 
     /**
      * Initialize system properties using build provided values.
